@@ -62,6 +62,25 @@ agent.
     $c->$cb({ foo => 123 }, 200);
   }
 
+=head2 Protected API
+
+It is possible to protect your API, using a custom route:
+
+  use Mojolicious::Lite;
+
+  my $route = app->routes->bridge->to(
+    cb => sub {
+      my $c = shift;
+      return 1 if $c->param('secret');
+      return $c->render(json => {error => "Not authenticated"}, status => 401);
+    }
+  );
+
+  plugin Swagger2 => {
+    route => $route,
+    url   => app->home->rel_file("api.yaml")
+  };
+
 =cut
 
 use Mojo::Base 'Mojolicious::Plugin';
@@ -110,7 +129,7 @@ document, like this:
     "errors": [
       {
         "message": "string value found, but a integer is required",
-        "property": "$.limit"
+        "path": "/limit"
       },
       ...
     ]
@@ -127,7 +146,7 @@ to render a JSON document, like this:
     "errors": [
       {
         "message": "is missing and it is required",
-        "property": "$.foo"
+        "path": "/foo"
       },
       ...
     ]
@@ -144,7 +163,7 @@ describing the errors. The default is to render a JSON document, like this:
     "errors": [
       {
         "message": "No handler defined.",
-        "property": null
+        "path": "/"
       }
     ]
   }
@@ -209,14 +228,16 @@ sub _generate_request_handler {
 
     unless (eval "require $controller;1") {
       $c->app->log->error($@);
-      return $c->_not_implemented($@);
+      return $c->render_swagger($self->_not_implemented('Controller not implemented.'), {}, 501);
     }
     unless ($method_ref = $controller->can($method)) {
       $method_ref = $controller->can(sprintf '%s_%s', $method, lc $c->req->method)
         and warn "HTTP method name is not used in method name lookup anymore!";
     }
     unless ($method_ref) {
-      return $c->render_swagger($self->_not_implemented, {}, 501);
+      $c->app->log->error(
+        qq(Can't locate object method "$method" via package "$controller. (Something is wrong in @{[$self->url]})"));
+      return $c->render_swagger($self->_not_implemented('Method not implemented.'), {}, 501);
     }
 
     bless $c, $controller;    # ugly hack?
@@ -244,33 +265,33 @@ sub _generate_request_handler {
 }
 
 sub _not_implemented {
-  my ($self, $err) = @_;
-  $err =~ s! at \S+.*!!s if $err;
-  return {valid => Mojo::JSON->false, errors => [{message => $err || 'No handler defined.', property => undef}]};
+  my ($self, $message) = @_;
+  return {valid => Mojo::JSON->false, errors => [{message => $message, path => '/'}]};
 }
 
 sub _validate_input {
   my ($self, $c, $config) = @_;
   my $headers = $c->req->headers;
   my $query   = $c->req->url->query;
-  my $body    = $c->req->json || $c->req->body_params->to_hash || {};
   my (%input, %v);
 
   for (@{$config->{parameters} || []}) {
     my $p = $_;
-    my @e;
-    my $in   = $p->{in};
-    my $name = $p->{name};
-    my $value
+    my ($in, $name) = @$p{qw( in name )};
+    my ($value, @e);
+
+    $value
       = $in eq 'query'  ? $query->param($name)
       : $in eq 'path'   ? $c->stash($name)
       : $in eq 'header' ? $headers->header($name)
-      :                   $body->{$name};
+      :                   $c->req->json || $c->req->body_params->to_hash || {};
 
     $p = $p->{schema} if $p->{schema};
 
     if (defined $value or $p->{required}) {
-      $value += 0 if $p->{type} and $p->{type} =~ /^(?:integer|number)/ and $value =~ /^\d/;
+      my $type = $p->{type} || 'object';
+      $value += 0 if $type =~ /^(?:integer|number)/ and $value =~ /^\d/;
+      $value = ($value eq 'false' or !$value) ? Mojo::JSON->false : Mojo::JSON->true if $type eq 'boolean';
       push @e, $self->_validator->validate({$name => $value}, {type => 'object', properties => {$name => $p}});
     }
 
@@ -278,7 +299,7 @@ sub _validate_input {
     push @{$v{errors}}, @e;
   }
 
-  $v{valid} = @{$v{errors}} ? Mojo::JSON->false : Mojo::JSON->true;
+  $v{valid} = @{$v{errors} || []} ? Mojo::JSON->false : Mojo::JSON->true;
   return \%v, \%input;
 }
 
