@@ -1,11 +1,17 @@
 package t::Api;
 use Mojo::Base 'Mojolicious::Controller';
 
-our $RES = {};
+our $RES  = {};
+our $CODE = 200;
+
+sub boolean_in_url {
+  my ($c, $args, $cb) = @_;
+  $c->$cb({p1 => $args->{p1}, q1 => $args->{q1}});
+}
 
 sub list_pets {
   my ($c, $args, $cb) = @_;
-  $c->$cb($RES);
+  $c->$cb($RES, $CODE);
 }
 
 sub show_pet_by_id {
@@ -15,9 +21,7 @@ sub show_pet_by_id {
 }
 
 sub add_pet {
-  my $self = shift;
-  $RES->{body} = $self->req->body;
-  $self->list_pets(@_);
+  shift->list_pets(@_);
 }
 
 sub update_pet {
